@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutSampler, TimeoutWatch
+from ocp_resources.utils import TimeoutSampler
 
 
 class Deployment(NamespacedResource):
@@ -21,11 +21,11 @@ class Deployment(NamespacedResource):
         Returns:
             Deployment is updated successfully
         """
-        super().to_dict()
-        self.res.update({"spec": {"replicas": replica_count}})
+        body = super().to_dict()
+        body.update({"spec": {"replicas": replica_count}})
 
         self.logger.info(f"Set deployment replicas: {replica_count}")
-        return self.update(resource_dict=self.res)
+        return self.update(resource_dict=body)
 
     def wait_for_replicas(self, deployed=True, timeout=TIMEOUT_4MINUTES):
         """
@@ -39,27 +39,19 @@ class Deployment(NamespacedResource):
             TimeoutExpiredError: If not availableReplicas is equal to replicas.
         """
         self.logger.info(f"Wait for {self.kind} {self.name} to be deployed: {deployed}")
-
-        timeout_watcher = TimeoutWatch(timeout=timeout)
-        for sample in TimeoutSampler(
+        samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            func=lambda: self.exists,
-        ):
-            if sample:
-                break
-
-        samples = TimeoutSampler(
-            wait_timeout=timeout_watcher.remaining_time(),
-            sleep=1,
             exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=lambda: self.instance,
+            func=self.api.get,
+            field_selector=f"metadata.name=={self.name}",
         )
         for sample in samples:
-            if sample:
-                status = sample.status
+            if sample.items:
+                instance = sample.items[0]
+                status = instance.status
 
-                spec_replicas = sample.spec.replicas
+                spec_replicas = instance.spec.replicas
                 total_replicas = status.replicas or 0
                 updated_replicas = status.updatedReplicas or 0
                 available_replicas = status.availableReplicas or 0
